@@ -70,7 +70,7 @@ class GetMediaShowItemView(BrowserView):
             return item.absolute_url()
         
         if item.portal_type == 'Image':
-            return leadMedia.getURL() + '/image_large'
+            return item.absolute_url() + '/image_large'
         
         if item.portal_type == 'Link' and (item.remoteUrl.find("youtube.com") > -1 or item.remoteUrl.find("vimeo.com") > -1):
             return item.remoteUrl
